@@ -1,22 +1,6 @@
-/*************************************************************************************
- * Copyright (C) 2001-2009 Anne-Marie Mahfouf <annma@kde.org>                        *
- * Copyright (C) 2014 Rahul Chowdhury <rahul.chowdhury@kdemail.net>                  *
- *                                                                                   *
- * This program is free software; you can redistribute it and/or modify              *
- * it under the terms of the GNU General Public License as published by              *
- * the Free Software Foundation; either version 2 of the License, or                 *
- * (at your option) any later version.                                               *
- *                                                                                   *
- * This program is distributed in the hope that it will be useful,                   *
- * but WITHOUT ANY WARRANTY; without even the implied warranty of                    *
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the                     *
- * GNU General Public License for more details.                                      *
- *                                                                                   *
- * You should have received a copy of the GNU General Public License                 *
- * along with this program; if not, write to the Free Software                       *
- * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.   *
- *************************************************************************************/
-
+// SPDX-FileCopyrightText: 2001-2009 Anne-Marie Mahfouf <annma@kde.org>
+// SPDX-FileCopyCopyright: 2014 Rahul Chowdhury <rahul.chowdhury@kdemail.net>
+// SPDX-License-Identifier: GPL-2.0-or-later
 
 #include "khangman.h"
 #include "khangman_version.h"
@@ -24,6 +8,7 @@
 #include <KAboutData>
 
 #include <KLocalizedString>
+#include <KLocalizedContext>
 #include <KCrash>
 
 #include <QApplication>
@@ -32,6 +17,9 @@
 #include <QStandardPaths>
 #include <QQmlEngine>
 #include <QCommandLineParser>
+#include <QQmlContext>
+#include <QIcon>
+#include <QQmlApplicationEngine>
 
 int main(int argc, char **argv)
 {
@@ -140,9 +128,15 @@ int main(int argc, char **argv)
         QFontDatabase::addApplicationFont(QStandardPaths::locate(QStandardPaths::AppLocalDataLocation, QStringLiteral("fonts/Dustismo_Roman.ttf")));
     }
 
-    KHangMan hangman;
-    QObject::connect(hangman.getEngine(), &QQmlEngine::quit, &app, &QCoreApplication::quit);
-    hangman.show();
+    QQmlApplicationEngine engine;
+    engine.rootContext()->setContextObject(new KLocalizedContext(&engine));
+
+    engine.loadFromModule(QStringLiteral("org.kde.khangman"), QStringLiteral("Main"));
+    if (engine.rootObjects().isEmpty()) {
+        return -1;
+    }
+
+    QObject::connect(&engine, &QQmlEngine::quit, &app, &QCoreApplication::quit);
     return app.exec();
 }
 
